pub struct ForkSessionSnapshot<'a> {
pub new_session_id: &'a str,
pub source_session_id: &'a str,
pub status: &'a str,
}Expand description
Borrowed identifiers used to persist one forked session snapshot.
Fields
new_session_id: &'a strStable id assigned to the newly forked session.
source_session_id: &'a strStable id of the source session whose metadata and transcript are copied.
status: &'a strInitial lifecycle status for the forked session.