pub struct ProjectListRow {Show 13 fields
pub active_session_count: i64,
pub created_at: i64,
pub display_name: Option<String>,
pub git_branch: Option<String>,
pub id: i64,
pub input_tokens: i64,
pub is_favorite: bool,
pub last_opened_at: Option<i64>,
pub last_session_updated_at: Option<i64>,
pub output_tokens: i64,
pub path: String,
pub session_count: i64,
pub updated_at: i64,
}Expand description
Row returned when loading one project with aggregated session statistics.
Fields
active_session_count: i64Number of sessions in an active lifecycle state.
created_at: i64Project creation timestamp in Unix seconds.
display_name: Option<String>Optional user-defined display name.
git_branch: Option<String>Last observed branch for the project checkout.
id: i64Stable project identifier.
input_tokens: i64Total input tokens accumulated by sessions in this project.
is_favorite: boolWhether the project is pinned ahead of other projects.
last_opened_at: Option<i64>Most recent project-open timestamp in Unix seconds.
last_session_updated_at: Option<i64>Most recent session update timestamp in Unix seconds.
output_tokens: i64Total output tokens accumulated by sessions in this project.
path: StringPersisted project checkout path.
session_count: i64Total sessions belonging to the project.
updated_at: i64Last project metadata update timestamp in Unix seconds.