pub struct ProjectRow {
pub created_at: i64,
pub display_name: Option<String>,
pub git_branch: Option<String>,
pub id: i64,
pub is_favorite: bool,
pub last_opened_at: Option<i64>,
pub path: String,
pub updated_at: i64,
}Expand description
Row returned when loading a project from the project table.
Fields
created_at: i64Creation timestamp in Unix seconds.
display_name: Option<String>Optional user-defined display name.
git_branch: Option<String>Last observed branch for the project checkout.
id: i64Stable database identifier.
is_favorite: boolWhether the project is pinned ahead of other projects.
last_opened_at: Option<i64>Most recent project-open timestamp in Unix seconds.
path: StringPersisted project checkout path.
updated_at: i64Last metadata update timestamp in Unix seconds.