pub struct SessionOrchestrationMetadataRow {
pub controller_session_id: Option<String>,
pub orchestration_status: Option<String>,
pub running_task_count: i64,
pub session_id: String,
pub waiting_task_count: i64,
}Expand description
Bulk-loaded controller progress and child adjacency for one session row.
Fields
controller_session_id: Option<String>Owning controller for an orchestration child, when this is a child row.
orchestration_status: Option<String>Latest orchestration status for a controller row, when this is a controller.
running_task_count: i64Number of child tasks currently creating or running.
session_id: StringSession receiving the derived metadata.
waiting_task_count: i64Number of child tasks currently waiting for user input.